@@ -1,7 +1,7 @@
 package Acme::CPANModules::TextTable;
 
 our $DATE = '2020-08-10'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -121,7 +121,7 @@ our $LIST = {
             features => {
                 wide_char => 0,
                 color => 1,
-                box_char => 0,
+                box_char => 1,
             },
         },
         {
@@ -255,7 +255,7 @@ Acme::CPANModules::TextTable - Modules that generate text tables
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::TextTable (from Perl distribution Acme-CPANModules-TextTable), released on 2020-08-10.
+This document describes version 0.005 of Acme::CPANModules::TextTable (from Perl distribution Acme-CPANModules-TextTable), released on 2020-08-10.
 
 =head1 SYNOPSIS
 
@@ -426,21 +426,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
  | participant                   | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | Text::ANSITable               |       2.6 |     380   |                 0.00% |             16761.03% |   0.0015  |      20 |
- | Text::ASCIITable              |      11   |      87   |               333.66% |              3788.05% |   0.00039 |      20 |
- | Text::Table::TinyColorWide    |      16   |      61   |               520.35% |              2617.98% |   0.00024 |      20 |
- | Text::FormatTable             |      18   |      57   |               567.02% |              2427.81% |   0.00021 |      20 |
- | Text::Table::TinyWide         |      23   |      43   |               783.26% |              1808.95% |   0.00022 |      20 |
- | Text::TabularDisplay          |      40   |      20   |              1499.37% |               954.23% |   0.00026 |      20 |
- | Text::Table::TinyColor        |      61   |      16   |              2204.74% |               631.58% |   0.00012 |      20 |
- | Text::Table::Tiny             |      67   |      15   |              2451.72% |               560.77% | 3.5e-05   |      21 |
- | Text::MarkdownTable           |      89   |      11   |              3273.84% |               399.76% | 3.1e-05   |      20 |
- | Text::Table                   |     110   |       9   |              4102.66% |               301.20% | 4.4e-05   |      20 |
- | Text::Table::HTML::DataTables |     120   |       8.2 |              4530.68% |               264.12% | 3.9e-05   |      20 |
- | Text::Table::HTML             |     120   |       8.1 |              4547.02% |               262.84% | 3.8e-05   |      20 |
- | Text::Table::CSV              |     220   |       4.6 |              8082.09% |               106.07% | 2.2e-05   |      20 |
- | Text::Table::Org              |     220   |       4.5 |              8294.84% |               100.85% | 3.4e-05   |      20 |
- | Text::Table::Sprintf          |     450   |       2.2 |             16761.03% |                 0.00% | 1.6e-05   |      20 |
+ | Text::ANSITable               |       2.7 |     370   |                 0.00% |             15633.54% |   0.0011  |      20 |
+ | Text::ASCIITable              |      11   |      87   |               322.58% |              3623.18% |   0.00034 |      21 |
+ | Text::Table::TinyColorWide    |      17   |      60   |               510.11% |              2478.80% |   0.00031 |      21 |
+ | Text::FormatTable             |      18   |      56   |               555.23% |              2301.23% |   0.00027 |      20 |
+ | Text::Table::TinyWide         |      23   |      44   |               740.72% |              1771.44% |   0.00038 |      20 |
+ | Text::TabularDisplay          |      44   |      23   |              1532.02% |               864.05% |   0.00017 |      20 |
+ | Text::Table::TinyColor        |      61   |      16   |              2134.53% |               604.11% | 5.9e-05   |      20 |
+ | Text::Table::Tiny             |      64   |      16   |              2269.75% |               563.93% | 3.8e-05   |      20 |
+ | Text::MarkdownTable           |      89   |      11   |              3179.63% |               379.73% | 5.7e-05   |      20 |
+ | Text::Table                   |     100   |       9   |              3820.67% |               301.30% |   0.00011 |      20 |
+ | Text::Table::HTML::DataTables |     130   |       7.9 |              4584.70% |               235.85% | 1.5e-05   |      20 |
+ | Text::Table::HTML             |     130   |       7.9 |              4587.60% |               235.64% | 1.3e-05   |      20 |
+ | Text::Table::CSV              |     240   |       4.2 |              8578.87% |                81.29% | 6.5e-06   |      20 |
+ | Text::Table::Org              |     240   |       4.2 |              8704.72% |                78.69% | 1.4e-05   |      20 |
+ | Text::Table::Sprintf          |     430   |       2.3 |             15633.54% |                 0.00% | 1.8e-05   |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
  #table2#
@@ -448,21 +448,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
  | participant                   | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | Text::ANSITable               |        25 |    40     |                 0.00% |             12440.24% |   0.00015 |      20 |
- | Text::ASCIITable              |       120 |     8.5   |               364.79% |              2598.03% | 6.2e-05   |      21 |
- | Text::FormatTable             |       160 |     6.3   |               531.87% |              1884.61% | 1.5e-05   |      20 |
- | Text::Table::TinyColorWide    |       160 |     6.2   |               541.51% |              1854.80% | 3.5e-05   |      20 |
- | Text::Table::TinyWide         |       240 |     4.2   |               834.16% |              1242.40% | 1.1e-05   |      20 |
- | Text::TabularDisplay          |       340 |     3     |              1225.24% |               846.26% | 1.9e-05   |      21 |
- | Text::MarkdownTable           |       430 |     2.3   |              1584.10% |               644.63% | 1.5e-05   |      20 |
- | Text::Table                   |       500 |     2     |              1863.78% |               538.58% | 1.1e-05   |      20 |
- | Text::Table::Tiny             |       590 |     1.7   |              2227.61% |               438.76% | 2.9e-06   |      20 |
- | Text::Table::TinyColor        |       590 |     1.7   |              2240.66% |               435.76% | 1.3e-05   |      20 |
- | Text::Table::HTML::DataTables |       970 |     1     |              3725.85% |               227.78% | 7.6e-06   |      20 |
- | Text::Table::HTML             |      1000 |     0.96  |              4016.61% |               204.63% | 4.5e-06   |      20 |
- | Text::Table::CSV              |      1800 |     0.57  |              6889.39% |                79.42% | 6.9e-07   |      20 |
- | Text::Table::Org              |      1800 |     0.556 |              7009.65% |                76.38% | 4.8e-07   |      20 |
- | Text::Table::Sprintf          |      3200 |     0.32  |             12440.24% |                 0.00% | 6.8e-07   |      21 |
+ | Text::ANSITable               |        20 |    50     |                 0.00% |             13649.56% |   0.00049 |      20 |
+ | Text::ASCIITable              |       120 |     8     |               470.78% |              2308.92% | 2.1e-05   |      20 |
+ | Text::FormatTable             |       160 |     6.2   |               639.62% |              1759.00% | 1.1e-05   |      20 |
+ | Text::Table::TinyColorWide    |       170 |     6     |               665.05% |              1697.21% | 2.2e-05   |      20 |
+ | Text::Table::TinyWide         |       230 |     4.3   |               976.30% |              1177.48% | 2.1e-05   |      20 |
+ | Text::TabularDisplay          |       350 |     2.9   |              1495.09% |               761.99% | 1.5e-05   |      20 |
+ | Text::MarkdownTable           |       420 |     2.4   |              1806.01% |               621.38% | 2.1e-05   |      20 |
+ | Text::Table                   |       510 |     1.9   |              2254.22% |               484.04% | 8.7e-06   |      20 |
+ | Text::Table::Tiny             |       550 |     1.8   |              2426.47% |               444.22% | 9.4e-06   |      20 |
+ | Text::Table::TinyColor        |       580 |     1.7   |              2579.14% |               413.21% | 1.1e-05   |      20 |
+ | Text::Table::HTML::DataTables |       990 |     1     |              4425.78% |               203.81% | 7.6e-06   |      21 |
+ | Text::Table::HTML             |      1100 |     0.92  |              4909.46% |               174.47% | 1.3e-06   |      20 |
+ | Text::Table::CSV              |      1810 |     0.551 |              8226.13% |                65.14% | 2.7e-07   |      20 |
+ | Text::Table::Org              |      1800 |     0.54  |              8350.51% |                62.71% | 1.1e-06   |      21 |
+ | Text::Table::Sprintf          |      3000 |     0.3   |             13649.56% |                 0.00% | 6.3e-06   |      21 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
  #table3#
@@ -470,21 +470,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Text::ANSITable               |       960 |  1000     |                 0.00% |              9820.22% | 8.7e-06 |      20 |
- | Text::ASCIITable              |      4900 |   210     |               406.80% |              1857.42% | 9.1e-07 |      20 |
- | Text::FormatTable             |      6900 |   140     |               617.83% |              1281.97% | 4.8e-07 |      20 |
- | Text::Table::TinyColorWide    |      7500 |   130     |               682.13% |              1168.37% | 8.5e-07 |      20 |
- | Text::Table                   |      7700 |   130     |               698.19% |              1142.83% | 1.9e-07 |      24 |
- | Text::Table::TinyWide         |     11000 |    91     |              1037.74% |               771.93% | 2.1e-07 |      20 |
- | Text::MarkdownTable           |     12000 |    81     |              1191.67% |               668.02% | 9.4e-08 |      26 |
- | Text::TabularDisplay          |     15000 |    66     |              1486.35% |               525.35% | 9.5e-08 |      25 |
- | Text::Table::Tiny             |     21000 |    48     |              2049.30% |               361.55% | 1.1e-07 |      20 |
- | Text::Table::HTML::DataTables |     23000 |    43     |              2292.39% |               314.66% | 6.7e-08 |      20 |
- | Text::Table::TinyColor        |     24000 |    41     |              2409.65% |               295.28% | 5.3e-08 |      20 |
- | Text::Table::HTML             |     47000 |    21     |              4808.67% |               102.10% | 2.7e-08 |      20 |
- | Text::Table::Org              |     55000 |    18.2   |              5624.03% |                73.31% | 6.7e-09 |      20 |
- | Text::Table::CSV              |     77523 |    12.899 |              7961.45% |                23.06% | 2.3e-11 |      20 |
- | Text::Table::Sprintf          |     95000 |    10     |              9820.22% |                 0.00% | 1.3e-08 |      20 |
+ | Text::ANSITable               |       980 |    1000   |                 0.00% |              9795.39% | 5.9e-06 |      20 |
+ | Text::ASCIITable              |      4800 |     210   |               391.26% |              1914.28% | 6.4e-07 |      20 |
+ | Text::FormatTable             |      7000 |     140   |               617.31% |              1279.51% | 2.1e-07 |      21 |
+ | Text::Table                   |      7700 |     130   |               682.99% |              1163.79% | 2.4e-07 |      25 |
+ | Text::Table::TinyColorWide    |      7800 |     130   |               699.94% |              1137.01% | 2.1e-07 |      21 |
+ | Text::Table::TinyWide         |     11000 |      90   |              1030.32% |               775.45% | 1.1e-07 |      20 |
+ | Text::MarkdownTable           |     10000 |      90   |              1033.55% |               772.96% | 1.8e-06 |      20 |
+ | Text::TabularDisplay          |     15000 |      65   |              1475.59% |               528.04% | 9.2e-08 |      27 |
+ | Text::Table::Tiny             |     21000 |      48   |              2018.65% |               367.06% | 6.7e-08 |      20 |
+ | Text::Table::HTML::DataTables |     23000 |      44   |              2238.39% |               323.17% | 1.1e-07 |      20 |
+ | Text::Table::TinyColor        |     24000 |      42   |              2345.56% |               304.63% | 5.3e-08 |      20 |
+ | Text::Table::HTML             |     47500 |      21   |              4742.64% |               104.34% |   2e-08 |      20 |
+ | Text::Table::Org              |     56000 |      18   |              5604.92% |                73.45% | 2.7e-08 |      20 |
+ | Text::Table::CSV              |     80800 |      12.4 |              8134.77% |                20.17% |   1e-08 |      20 |
+ | Text::Table::Sprintf          |     97100 |      10.3 |              9795.39% |                 0.00% | 3.3e-09 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table4#
@@ -492,21 +492,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Text::ANSITable               |      3700 |    270    |                 0.00% |              7771.18% | 1.1e-06 |      20 |
- | Text::ASCIITable              |     17000 |     58    |               368.96% |              1578.42% | 1.3e-07 |      20 |
- | Text::Table                   |     20000 |     49    |               453.69% |              1321.57% | 1.6e-07 |      20 |
- | Text::MarkdownTable           |     25000 |     41    |               565.30% |              1083.10% |   1e-07 |      21 |
- | Text::FormatTable             |     34000 |     29    |               829.44% |               746.88% | 6.5e-08 |      21 |
- | Text::Table::HTML::DataTables |     37000 |     27    |               886.46% |               697.92% | 5.1e-08 |      22 |
- | Text::Table::TinyWide         |     40000 |     20    |              1056.14% |               580.82% | 7.4e-07 |      22 |
- | Text::Table::TinyColorWide    |     44000 |     23    |              1081.99% |               565.92% | 2.7e-08 |      20 |
- | Text::TabularDisplay          |     61000 |     16    |              1550.59% |               376.87% | 2.7e-08 |      20 |
- | Text::Table::Tiny             |     64000 |     16    |              1633.92% |               353.95% | 5.3e-08 |      20 |
- | Text::Table::TinyColor        |     92600 |     10.8  |              2401.55% |               214.65% | 9.5e-09 |      22 |
- | Text::Table::Org              |    148000 |      6.75 |              3902.12% |                96.68% | 3.3e-09 |      20 |
- | Text::Table::HTML             |    185000 |      5.41 |              4892.61% |                57.66% | 1.5e-09 |      25 |
- | Text::Table::Sprintf          |    280000 |      3.6  |              7417.74% |                 4.70% | 6.4e-09 |      22 |
- | Text::Table::CSV              |    290000 |      3.4  |              7771.18% |                 0.00% |   5e-09 |      20 |
+ | Text::ANSITable               |      3800 |    260    |                 0.00% |              7500.38% | 6.6e-07 |      22 |
+ | Text::ASCIITable              |     18000 |     57    |               358.01% |              1559.43% | 1.1e-07 |      20 |
+ | Text::Table                   |     21000 |     48    |               445.20% |              1294.04% | 1.1e-07 |      20 |
+ | Text::MarkdownTable           |     25000 |     40    |               551.77% |              1066.11% | 1.1e-07 |      20 |
+ | Text::FormatTable             |     34000 |     29    |               794.08% |               750.08% |   5e-08 |      23 |
+ | Text::Table::HTML::DataTables |     38000 |     26    |               887.99% |               669.28% | 5.3e-08 |      20 |
+ | Text::Table::TinyColorWide    |     44000 |     23    |              1054.15% |               558.53% | 2.7e-08 |      20 |
+ | Text::Table::TinyWide         |     50000 |     20    |              1112.17% |               527.00% | 3.6e-07 |      24 |
+ | Text::TabularDisplay          |     62000 |     16    |              1520.67% |               368.97% | 2.7e-08 |      20 |
+ | Text::Table::Tiny             |     63000 |     16    |              1546.42% |               361.63% | 3.3e-08 |      20 |
+ | Text::Table::TinyColor        |     94000 |     11    |              2352.06% |               209.96% | 1.3e-08 |      20 |
+ | Text::Table::Org              |    151000 |      6.61 |              3852.70% |                92.28% | 3.3e-09 |      21 |
+ | Text::Table::HTML             |    180000 |      5.6  |              4571.03% |                62.71% | 6.7e-09 |      20 |
+ | Text::Table::Sprintf          |    200000 |      4    |              6351.94% |                17.80% | 5.7e-08 |      20 |
+ | Text::Table::CSV              |    290000 |      3.4  |              7500.38% |                 0.00% | 6.7e-09 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table5#
@@ -514,47 +514,47 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Text::ANSITable               |       120 |    8.3    |                 0.00% |             11903.43% | 3.2e-05 |      20 |
- | Text::ASCIITable              |       530 |    1.9    |               336.04% |              2652.85% |   3e-06 |      20 |
- | Text::FormatTable             |       730 |    1.4    |               504.55% |              1885.52% | 2.9e-06 |      20 |
- | Text::Table::TinyColorWide    |       870 |    1.2    |               615.28% |              1578.15% | 2.7e-06 |      20 |
- | Text::Table                   |      1200 |    0.83   |               888.71% |              1114.04% | 1.1e-06 |      20 |
- | Text::Table::TinyWide         |      1200 |    0.82   |               905.59% |              1093.68% | 3.2e-06 |      20 |
- | Text::Table::TinyColor        |      1600 |    0.64   |              1180.37% |               837.49% | 4.2e-06 |      20 |
- | Text::TabularDisplay          |      2310 |    0.432  |              1810.35% |               528.34% | 4.3e-07 |      20 |
- | Text::Table::Tiny             |      3070 |    0.326  |              2430.80% |               374.29% | 2.1e-07 |      20 |
- | Text::MarkdownTable           |      3600 |    0.28   |              2859.84% |               305.54% | 6.4e-07 |      20 |
- | Text::Table::HTML::DataTables |      5660 |    0.177  |              4568.99% |               157.09% | 5.2e-08 |      21 |
- | Text::Table::HTML             |      6400 |    0.16   |              5220.86% |               125.59% |   2e-07 |      23 |
- | Text::Table::Org              |      9070 |    0.11   |              7383.21% |                60.40% | 5.3e-08 |      20 |
- | Text::Table::CSV              |     11900 |    0.0837 |              9756.52% |                21.78% | 2.7e-08 |      20 |
- | Text::Table::Sprintf          |     15000 |    0.069  |             11903.43% |                 0.00% |   8e-08 |      20 |
+ | Text::ANSITable               |       130 |     8     |                 0.00% |             11509.16% | 1.5e-05 |      20 |
+ | Text::ASCIITable              |       520 |     1.9   |               315.64% |              2693.06% | 4.1e-06 |      20 |
+ | Text::FormatTable             |       720 |     1.4   |               474.77% |              1919.79% |   5e-06 |      20 |
+ | Text::Table::TinyColorWide    |       850 |     1.2   |               579.94% |              1607.38% | 3.4e-06 |      20 |
+ | Text::Table                   |      1200 |     0.83  |               858.40% |              1111.31% | 2.2e-06 |      20 |
+ | Text::Table::TinyWide         |      1200 |     0.81  |               880.96% |              1083.44% | 9.1e-07 |      20 |
+ | Text::TabularDisplay          |      2300 |     0.43  |              1757.95% |               524.84% | 6.9e-07 |      20 |
+ | Text::Table::Tiny             |      3000 |     0.34  |              2250.85% |               393.83% | 1.1e-06 |      20 |
+ | Text::Table::TinyColor        |      3100 |     0.33  |              2342.20% |               375.36% | 4.3e-07 |      20 |
+ | Text::MarkdownTable           |      3600 |     0.28  |              2768.12% |               304.77% | 6.9e-07 |      20 |
+ | Text::Table::HTML::DataTables |      5700 |     0.18  |              4402.09% |               157.86% | 2.7e-07 |      20 |
+ | Text::Table::HTML             |      6620 |     0.151 |              5164.87% |               120.50% | 5.2e-08 |      21 |
+ | Text::Table::Org              |      9300 |     0.11  |              7322.71% |                56.40% | 2.1e-07 |      20 |
+ | Text::Table::CSV              |     12200 |     0.082 |              9605.19% |                19.62% |   8e-08 |      20 |
+ | Text::Table::Sprintf          |     15000 |     0.069 |             11509.16% |                 0.00% | 1.3e-07 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher --cpanmodules-module TextTable --module-startup >>):
 
  #table6#
- +-------------------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
- | participant                   | time (ms) | mod_overhead_time  | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
- +-------------------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
- | Text::ANSITable               |     53    | 45                 |                 0.00% |               571.81% |   0.00026 |      20 |
- | Text::MarkdownTable           |     45    | 37                 |                18.67% |               466.09% |   0.0003  |      20 |
- | Text::Table::TinyColorWide    |     33    | 25                 |                61.65% |               315.61% | 8.6e-05   |      20 |
- | Text::Table::TinyWide         |     31    | 23                 |                72.49% |               289.49% |   0.00016 |      20 |
- | Text::Table                   |     23    | 15                 |               135.78% |               184.93% |   7e-05   |      20 |
- | Text::ASCIITable              |     18    | 10                 |               199.24% |               124.51% | 5.8e-05   |      20 |
- | Text::Table::Tiny             |     15    |  7                 |               252.52% |                90.57% | 2.1e-05   |      20 |
- | Text::FormatTable             |     15    |  7                 |               265.13% |                83.99% | 5.5e-05   |      21 |
- | Text::Table::TinyColor        |     14    |  6                 |               286.37% |                73.88% | 3.5e-05   |      20 |
- | Text::TabularDisplay          |     10.6  |  2.6               |               402.33% |                33.74% | 1.1e-05   |      20 |
- | Text::Table::HTML::DataTables |     10    |  2                 |               410.17% |                31.68% | 6.3e-05   |      20 |
- | Text::Table::HTML             |      9.85 |  1.85              |               442.91% |                23.74% | 9.2e-06   |      20 |
- | Text::Table::Sprintf          |      8.5  |  0.5               |               532.31% |                 6.25% | 3.9e-05   |      20 |
- | Text::Table::CSV              |      8.4  |  0.4               |               539.98% |                 4.97% | 2.2e-05   |      20 |
- | Text::Table::Org              |      8.2  |  0.199999999999999 |               548.17% |                 3.65% | 1.9e-05   |      21 |
- | perl -e1 (baseline)           |      8    |  0                 |               571.81% |                 0.00% | 6.7e-05   |      20 |
- +-------------------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
+ +-------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ | participant                   | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
+ +-------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ | Text::ANSITable               |      55   |              46.4 |                 0.00% |               605.95% |   0.00023 |      20 |
+ | Text::MarkdownTable           |      43   |              34.4 |                28.89% |               447.69% |   0.00013 |      20 |
+ | Text::Table::TinyColorWide    |      33   |              24.4 |                68.74% |               318.38% | 7.3e-05   |      20 |
+ | Text::Table::TinyWide         |      32   |              23.4 |                72.30% |               309.72% |   0.00012 |      20 |
+ | Text::Table                   |      21.9 |              13.3 |               152.58% |               179.49% |   2e-05   |      20 |
+ | Text::ASCIITable              |      18   |               9.4 |               207.79% |               129.36% | 9.1e-05   |      20 |
+ | Text::Table::Tiny             |      15   |               6.4 |               267.30% |                92.20% | 4.4e-05   |      23 |
+ | Text::FormatTable             |      14   |               5.4 |               287.86% |                82.01% | 2.8e-05   |      20 |
+ | Text::Table::TinyColor        |      14   |               5.4 |               309.25% |                72.50% | 3.6e-05   |      21 |
+ | Text::Table::HTML             |      10   |               1.4 |               356.93% |                54.50% |   0.00031 |      20 |
+ | Text::Table::HTML::DataTables |      10   |               1.4 |               411.84% |                37.92% |   0.00022 |      23 |
+ | Text::TabularDisplay          |      10   |               1.4 |               430.28% |                33.13% | 2.8e-05   |      20 |
+ | Text::Table::Sprintf          |       9.6 |               1   |               474.16% |                22.95% | 3.4e-05   |      20 |
+ | Text::Table::Org              |       9   |               0.4 |               528.40% |                12.34% |   0.00016 |      20 |
+ | perl -e1 (baseline)           |       8.6 |               0   |               541.15% |                10.11% |   4e-05   |      21 |
+ | Text::Table::CSV              |       7.8 |              -0.8 |               605.95% |                 0.00% | 2.1e-05   |      21 |
+ +-------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -569,7 +569,7 @@ To display as an interactive HTML table on a browser, you can add option C<--for
  | Text::FormatTable             | no           | no        | no            |
  | Text::MarkdownTable           | no           | no        | no            |
  | Text::Table                   | N/A *4)      | no        | no            |
- | Text::Table::Tiny             | no           | yes       | no            |
+ | Text::Table::Tiny             | yes          | yes       | no            |
  | Text::Table::Sprintf          | no           | no        | no            |
  | Text::Table::TinyColor        | no           | yes       | no            |
  | Text::Table::TinyColorWide    | no           | yes       | yes           |
